@@ -26,16 +26,20 @@ def get_dict_mat():
         json_data = json.load(f)
     return json_data
 
-class dict_mat():
-    def __init__(self):
-        self.dict_Materials = self.getvalue()
-    
-    def getvalue(self):
-        with open(resource_path('material.json'),'r') as f:
+def get_dict_detector():
+    with open(resource_path('detector_config.json'),'r') as f:
+        json_data = json.load(f)
+    return json_data
+
+def get_detector_geom():
+    try:
+        with open(resource_path('detector_geometry.json'),'r') as f:
             json_data = json.load(f)
-        return json_data
-    
-    
+        return json_data["default"]
+    except:
+        print("Default top reflection geometry")
+        return "Z>0"
+
 dict_Materials = get_dict_mat()
 dict_Materials_short = get_dict_mat()
     
@@ -46,15 +50,12 @@ def get_extinct_mat():
 
 dict_Extinc = get_extinct_mat()
 dict_Extinc_inv = get_extinct_mat()
- 
-dict_Stiffness = {"Ge": ["Ge", [126, 44, 67.7], "cubic"]}
-
 
 ######## Geometrey Default  ##############
 # Default constant
 DEFAULT_DETECTOR_DISTANCE = 70.0  # mm
 DEFAULT_DETECTOR_DIAMETER = 165.0  # mm
-DEFAULT_TOP_GEOMETRY = "Z>0"
+DEFAULT_TOP_GEOMETRY = get_detector_geom()
 
 #############   2D DETECTOR ##############
 LAUEIMAGING_DATA_FORMAT = "uint16"  # 'uint8'
@@ -74,41 +75,9 @@ CCD_CALIBRATION_PARAMETERS = ["dd", "xcen", "ycen", "xbet", "xgam", "pixelsize",
 # binary encoding format,
 # description,
 # file extension
-dict_CCD = {
-    "MARCCD165": ((2048, 2048), 0.079142, 65535, "no", 4096, "uint16", "MAR Research 165 mm now rayonix", "mccd", ),
-    "sCMOS": [(2018, 2016), 0.0734, 65535, "no", 3828, "uint16", "file as produced by sCMOS camera with checked fliplr transform. CCD parameters read from tif header by fabio", "tif"],
-    "cor": [(2018, 2016), 0.0734, 65535, "no", 3828, "uint16", "file as produced by sCMOS camera with checked fliplr transform. CCD parameters read from tif header by fabio", "cor"],
-    "cor_16M": [(2 * 2018, 2 * 2016), 0.0734 / 2.0, 65535, "no", 3828, "uint16", "binned 1x1, CCD parameters binned 1x1 read from tif header by fabio ", "cor"],
-    "sCMOS_fliplr": [(2018, 2016), 0.0734, 65535, "sCMOS_fliplr", 3828, "uint16", "binned 2x2, CCD parameters read from tif header by fabio", "tif"],
-    "sCMOS_fliplr_16M": [(2 * 2018, 2 * 2016), 0.0734 / 2.0, 65535, "sCMOS_fliplr", 3828, "uint16", "binned 1x1, CCD parameters binned 1x1 read from tif header by fabio ", "tif"],
-    "sCMOS_16M": [(2 * 2018, 2 * 2016), 0.0734 / 2.0, 65535, "no", 3828, "uint16", "binned 1x1, CCD parameters binned 1x1 read from tif header by fabio ", "tif"],
-    "psl_weiwei": [(1247, 1960), 0.075, 65535, "no", -1, "uint16", "camera from desy photonics science 1247*1960 ", "tif", ],
-    "VHR_full": ((2671, 4008), 0.031, 10000, "vhr", 4096, "uint16", "NOT USED: very basic vhr settings, the largest frame available without grid correction", "tiff"),
-    "VHR_diamond": ((2594, 3764), 0.031, 10000, "vhr", 4096, "uint16", "first vhr settings of Jun 12 close to diamond 2theta axis displayed is vertical, still problem with fit from PeakSearchGUI", "tiff"),
-    "VHR_small": ((2594, 2748), 0.031, 10000, "vhr", 4096, "uint16", "vhr close to diamond Nov12 frame size is lower than VHR_diamond", "tiff"),
-    "ImageStar": ((1500, 1500), 0.044, 65535, "vhr", 4096, "uint16", "Imagestar photonics Science close to diamond March13  extension is mar.tiff", "tiff"),
-    "ImageStar_raw_3056x3056": ((3056, 3056), 0.022, 64000, "vhr", 872, "uint16", "raw image Apr 2018 imagestar for diamond binning 1x1  .tif (could be read by VHR_DLS?)", "tif"),
-    "ImageStar_1528x1528": ((1528, 1528), 0.044, 65535, "vhr", 4096, "uint16", "Imagestar photonics Science close to diamond May 2018  extension is mar.tiff  non remapping 1528x1528", "tiff"),
-    "ImageDeathStar": ((1500, 1500), 0.044, 65535, "VHR_Feb13", 4096, "uint16", "Imagestar photonics Science close to sample, mounting similar to MARCCD, Sep14", "tif"),
-    "ImageStar_raw": ((1500, 1500), 0.044, 64000, "vhr", 872, "uint16", "raw image GISAXS BM32 November 2014 .tif", "tif"),
-    "ImageStar_dia_2021": ((3056, 3056), 0.022, 65535, "ImageStar_dia_2021", 4096, "uint16", "Imagestar photonics Science close to diamond March13  extension is mar.tiff", "tif"),
-    "VHR_diamond_Mar13": ((2594, 2774), 0.031, 10000, "vhr", 4096, "uint16", "vhr close to diamond Mar13 frame size is lower than VHR_diamond", "tiff"),
-    "VHR": ((2594, 3764), 0.031, 10000, "VHR_Feb13", 4096, "uint16", "vhr settings of Jun 12 2theta axis displayed is horizontal, no problem with fit from PeakSearchGUI", "tiff"),
-    "VHR_Feb13": ((2594, 2774), 0.031, 10000, "VHR_Feb13", 4096, "uint16", "vhr settings of Feb13 close to sample 2theta axis displayed is vertical, no problem with fit from PeakSearchGUI", "tiff"),
-    "VHR_Feb13_rawtiff": ((2594, 2774), 0.031, 10000, "VHR_Feb13", 110, "uint16", " ", "tiff"),
-    "VHR_PSI": ((2615, 3891), 0.0312, 65000, "no", 4096, "uint16", "vhr at psi actually read by libtiff (variable header size and compressed data)", "tif"),
-    "VHR_DLS": ((3056, 3056), 0.0312, 65000, "no", 4096, "uint16", "vhr at dls actually read by libtiff (variable header size and compressed data)", "tif"),
-    "PRINCETON": ((2048, 2048), 0.079, 57000, "no", 4096, "uint16", "ROPER Princeton Quadro 2048x2048 pixels converted from .spe to .mccd", "mccd"),  # 2X2, saturation value depends on gain and DAC
-    "FRELON": ((2048, 2048), 0.048, 65000, "frelon2", 1024, "uint16", "FRELON camera 2048x2048 pixels, 2theta axis is horizontal (edf format)", "edf"),
-    "TIFF Format": (-1, -1, "", "", "", "" "CCD parameters read from tiff header", "tiff", ),
-    "EDF": ((1065, 1030), 0.075, 650000000000, "no", 0, "uint32", "CCD parameters read from edf header EIGER", "edf", ),
-    "pnCCD": ((384, 384), 0.075, 65000, "no", 1024, "uint16", "pnCCD from SIEGEN only: pixel size and frame dimensions OK", "tiff"),
-    "pnCCD_Tuba": ((384, 384), 0.075, 10000000, "no", 258, "uint16", "pnCCD from Tuba only: pixel size and frame dimensions OK", "tiff"),
-    "EIGER_4M": ((2167, 2070), 0.075, 4294967295, "no", 0, "uint32", "CCD parameters read from tif header EIGER4M used at ALS", "tif"),
-    "EIGER_4Mstack": ((2167, 2070), 0.075, 4294967295, "no", 0, "uint32", "detector parameters read hdf5 EIGER4M stack used at SLS", "h5"),
-    "EIGER_4Munstacked": ((2167, 2070), 0.075, 4294967295, "no", 0, "uint32", "unstacked hdf5 EIGER4M  used at SLS", "unstacked"),
-    "EIGER_1M": ((1065, 1030), 0.075, 4294967295, "no", 0, "uint32", "CCD parameters read from edf header EIGER1M at BM32 ESRF", "edf"),
-}
+dict_CCD = get_dict_detector()
+
+dict_Stiffness = {"Ge": ["Ge", [126, 44, 67.7], "cubic"]}
 
 # ------------------------------------------------------
 # CCD pixels skewness:
@@ -172,26 +141,7 @@ dict_Vect = {
         [2.0 / 3, -1.0 / 3, 2.0 / 3],
         [-2.0 / 3, -2.0 / 3, 1.0 / 3],
     ],
-    # "sigma3_1": [
-    #     [-1.0 / 3, 2.0 / 3, 2.0 / 3],
-    #     [2.0 / 3, -1.0 / 3, 2.0 / 3],
-    #     [2.0 / 3, 2.0 / 3, -1.0 / 3],
-    # ],
-    # "sigma3_2": [
-    #     [-1.0 / 3, -2.0 / 3, 2.0 / 3],
-    #     [-2.0 / 3, -1.0 / 3, -2.0 / 3],
-    #     [2.0 / 3, -2.0 / 3, -1.0 / 3],
-    # ],
-    # "sigma3_3": [
-    #     [-1.0 / 3, 2.0 / 3, -2.0 / 3],
-    #     [2.0 / 3, -1.0 / 3, -2.0 / 3],
-    #     [-2.0 / 3, -2.0 / 3, -1.0 / 3],
-    # ],
-    # "sigma3_4": [
-    #     [-1.0 / 3, -2.0 / 3, -2.0 / 3],
-    #     [-2.0 / 3, -1.0 / 3, 2.0 / 3],
-    #     [-2.0 / 3, 2.0 / 3, -1.0 / 3],
-    # ],
+
     "shear1": [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.008, 0.0, 1.0]],
     "shear2": [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.016, 0.0, 1.0]],
     "shear3": [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.024, 0.0, 1.0]],
